@@ -4,6 +4,10 @@ import os
 if sys.version_info < (3, 8):
     raise ImportError("nanobind does not support Python < 3.8.")
 
+def source_dir() -> str:
+    "Return the path to the nanobind source directory."
+    return os.path.join(os.path.abspath(os.path.dirname(__file__)), "src")
+
 def include_dir() -> str:
     "Return the path to the nanobind include directory"
     return os.path.join(os.path.abspath(os.path.dirname(__file__)), "include")
@@ -12,10 +16,11 @@ def cmake_dir() -> str:
     "Return the path to the nanobind CMake module directory."
     return os.path.join(os.path.abspath(os.path.dirname(__file__)), "cmake")
 
-__version__ = "2.2.0"
+__version__ = "2.6.0"
 
 __all__ = (
     "__version__",
+    "source_dir",
     "include_dir",
     "cmake_dir",
 )
